@@ -22,25 +22,28 @@
 
 #include <kcombobox.h>
 #include <klocale.h>
-#include <kvbox.h>
+
 #include <QCheckBox>
 #include <QGroupBox>
 #include <QHBoxLayout>
 #include <QLabel>
+#include <QVBoxLayout>
 
 PushDialog::PushDialog (QWidget* parent ):
     KDialog (parent, Qt::Dialog)
 {
-    this->setCaption(i18nc("@title:window", "<application>Git</application> Push"));
+    this->setCaption(xi18nc("@title:window", "<application>Git</application> Push"));
     this->setButtons(KDialog::Ok | KDialog::Cancel);
     this->setDefaultButton(KDialog::Ok);
     this->setButtonText(KDialog::Ok, i18nc("@action:button", "Push"));
 
-    KVBox * vbox = new KVBox(this);
-    this->setMainWidget(vbox);
+    QWidget * boxWidget = new QWidget(this);
+    QVBoxLayout * boxLayout = new QVBoxLayout(boxWidget);
+    this->setMainWidget(boxWidget);
 
     //Destination
-    QGroupBox * destinationGroupBox = new QGroupBox(vbox);
+    QGroupBox * destinationGroupBox = new QGroupBox(boxWidget);
+    boxLayout->addWidget(destinationGroupBox);
     destinationGroupBox->setTitle(i18nc("@title:group The remote host", "Destination"));
     QHBoxLayout * destinationHBox = new QHBoxLayout(destinationGroupBox);
     destinationGroupBox->setLayout(destinationHBox);
@@ -52,7 +55,8 @@ PushDialog::PushDialog (QWidget* parent ):
     destinationHBox->addStretch();
 
     //Branches
-    QGroupBox* branchesGroupBox = new QGroupBox(vbox);
+    QGroupBox* branchesGroupBox = new QGroupBox(boxWidget);
+    boxLayout->addWidget(branchesGroupBox);
     branchesGroupBox->setTitle(i18nc("@title:group", "Branches"));
     QHBoxLayout * branchesHBox = new QHBoxLayout(branchesGroupBox);
     branchesGroupBox->setLayout(branchesHBox);
@@ -69,7 +73,8 @@ PushDialog::PushDialog (QWidget* parent ):
     m_remoteBranchComboBox = new KComboBox(false, branchesGroupBox);
     branchesHBox->addWidget(m_remoteBranchComboBox);
 
-    QGroupBox* optionsGroupBox = new QGroupBox(vbox);
+    QGroupBox* optionsGroupBox = new QGroupBox(boxWidget);
+    boxLayout->addWidget(optionsGroupBox);
     optionsGroupBox->setTitle(i18nc("@title:group", "Options"));
     QHBoxLayout * optionsHBox = new QHBoxLayout(optionsGroupBox);
     optionsGroupBox->setLayout(optionsHBox);
@@ -88,24 +93,16 @@ PushDialog::PushDialog (QWidget* parent ):
     int currentBranchIndex;
     QStringList branches = gitWrapper->branches(&currentBranchIndex);
 
-    for (int i=0; i < branches.size(); ++i){
-        if (branches[i].startsWith(QLatin1String("remotes/"))) {
-            const QStringList sections = branches[i].split('/');
-            if (sections.size() > 2) {
-                QHash<QString,QStringList>::iterator entry = m_remoteBranches.find(sections.at(1));
-                if (entry == m_remoteBranches.end()) {
-                    m_remoteBranches.insert(sections.at(1), QStringList() << sections.at(2));
-                } else {
-                    entry.value().append(sections.at(2));
-                }
-            }
+    foreach (const QString& branch, branches) {
+        if (branch.startsWith(QLatin1String("remotes/"))) {
+            const QString remote = branch.section('/', 1, 1);
+            const QString name = branch.section('/', 2);
+            m_remoteBranches[remote] << name;
         } else {
-            m_localBranchComboBox->addItem(branches[i]);
-            if (i == currentBranchIndex) {
-                 m_localBranchComboBox->setCurrentIndex(m_localBranchComboBox->count()-1);
-             }
+            m_localBranchComboBox->addItem(branch);
         }
     }
+    m_localBranchComboBox->setCurrentText(branches.at(currentBranchIndex));
     remoteSelectionChanged(m_remoteComboBox->currentText());
 
     //Signals
